# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['telegram_stats_bot']

package_data = \
{'': ['*']}

install_requires = \
['appdirs>=1.4.4,<2.0.0',
 'matplotlib>=3.2.1,<4.0.0',
 'numpy>=1.18.4,<2.0.0',
 'pandas>=1.0.4,<2.0.0',
 'python-telegram-bot>=12.7,<13.0',
 'seaborn>=0.10.1,<0.11.0',
 'sqlalchemy[postgresql_psycopg2binary]>=1.3.17,<2.0.0']

setup_kwargs = {
    'name': 'telegram-stats-bot',
    'version': '0.1.0',
    'description': 'A logging and statistics bot for Telegram based on python-telegram-bot.',
    'long_description': "==================\ntelegram-stats-bot\n==================\n\nTelegram-stats-bot is a simple bot that lives in your Telegram group, logging messages to a Postgresql database and\nserving statistical tables and plots to users as Telegram messages.\n\n.. image:: https://img.shields.io/pypi/v/dstat-interface.svg\n   :target: https://pypi.org/project/python-telegram-bot/\n   :alt: PyPi Package Version\n\n.. image:: https://img.shields.io/pypi/pyversions/dstat-interface.svg\n   :target: https://pypi.org/project/python-telegram-bot/\n   :alt: Supported Python versions\n\n.. image:: https://www.cpu.re/static/python-telegram-bot/downloads.svg\n   :target: https://www.cpu.re/static/python-telegram-bot/downloads-by-python-version.txt\n   :alt: PyPi Package Monthly Download\n\n.. image:: https://img.shields.io/badge/docs-latest-af1a97.svg\n   :target: https://python-telegram-bot.readthedocs.io/\n   :alt: Documentation Status\n\n.. image:: https://img.shields.io/pypi/l/dstat-interface.svg\n   :target: https://www.gnu.org/licenses/gpl-3.0-or-later.html\n   :alt: LGPLv3 License\n\n.. image:: https://github.com/python-telegram-bot/python-telegram-bot/workflows/GitHub%20Actions/badge.svg?event=schedule\n   :target: https://github.com/python-telegram-bot/python-telegram-bot/\n   :alt: Github Actions workflow\n\n.. image:: https://codecov.io/gh/python-telegram-bot/python-telegram-bot/branch/master/graph/badge.svg\n   :target: https://codecov.io/gh/python-telegram-bot/python-telegram-bot\n   :alt: Code coverage\n   \n.. image:: http://isitmaintained.com/badge/resolution/python-telegram-bot/python-telegram-bot.svg\n   :target: http://isitmaintained.com/project/python-telegram-bot/python-telegram-bot\n   :alt: Median time to resolve an issue\n\n.. image:: https://api.codacy.com/project/badge/Grade/99d901eaa09b44b4819aec05c330c968\n   :target: https://www.codacy.com/app/python-telegram-bot/python-telegram-bot?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=python-telegram-bot/python-telegram-bot&amp;utm_campaign=Badge_Grade\n   :alt: Code quality\n\n.. image:: https://img.shields.io/badge/Telegram-Group-blue.svg\n   :target: https://telegram.me/pythontelegrambotgroup\n   :alt: Telegram Group\n\n.. image:: https://img.shields.io/badge/IRC-Channel-blue.svg\n   :target: https://webchat.freenode.net/?channels=##python-telegram-bot\n   :alt: IRC Bridge\n\n-----------------\nTable of contents\n-----------------\n\n- `Introduction`_\n\n- `Telegram API support`_\n\n- `Installing`_\n\n- `Getting started`_\n\n  #. `Learning by example`_\n\n  #. `Logging`_\n\n  #. `Documentation`_\n\n- `Getting help`_\n\n- `Contributing`_\n\n- `License`_\n\n------------\nIntroduction\n------------\n\nThis library provides a pure Python interface for the\n`Telegram Bot API <https://core.telegram.org/bots/api>`_.\nIt's compatible with Python versions 3.5+ and `PyPy <http://pypy.org/>`_.\n\nIn addition to the pure API implementation, this library features a number of high-level classes to\nmake the development of bots easy and straightforward. These classes are contained in the\n``telegram.ext`` submodule.\n\n====================\nTelegram API support\n====================\n\nAll types and methods of the Telegram Bot API **4.8** are supported.\n\n==========\nInstalling\n==========\n\nYou can install or upgrade python-telegram-bot with:\n\n.. code:: shell\n\n    $ pip install python-telegram-bot --upgrade\n\nOr you can install from source with:\n\n.. code:: shell\n\n    $ git clone https://github.com/python-telegram-bot/python-telegram-bot --recursive\n    $ cd python-telegram-bot\n    $ python setup.py install\n    \nIn case you have a previously cloned local repository already, you should initialize the added urllib3 submodule before installing with:\n\n.. code:: shell\n\n    $ git submodule update --init --recursive\n\n===============\nGetting started\n===============\n\nOur Wiki contains a lot of resources to get you started with ``python-telegram-bot``:\n\n- `Introduction to the API <https://github.com/python-telegram-bot/python-telegram-bot/wiki/Introduction-to-the-API>`_\n- Tutorial: `Your first Bot <https://github.com/python-telegram-bot/python-telegram-bot/wiki/Extensions-%E2%80%93-Your-first-Bot>`_\n\nOther references:\n\n- `Telegram API documentation <https://core.telegram.org/bots/api>`_\n- `python-telegram-bot documentation <https://python-telegram-bot.readthedocs.io/>`_\n\n-------------------\nLearning by example\n-------------------\n\nWe believe that the best way to learn this package is by example. Here\nare some examples for you to review. Even if it is not your approach for learning, please take a\nlook at ``echobot2``, it is the de facto base for most of the bots out there. Best of all,\nthe code for these examples are released to the public domain, so you can start by grabbing the\ncode and building on top of it.\n\nVisit `this page <https://github.com/python-telegram-bot/python-telegram-bot/blob/master/examples/README.md>`_ to discover the official examples or look at the examples on the `wiki <https://github.com/python-telegram-bot/python-telegram-bot/wiki/Examples>`_ to see other bots the community has built.\n\n-------\nLogging\n-------\n\nThis library uses the ``logging`` module. To set up logging to standard output, put:\n\n.. code:: python\n\n    import logging\n    logging.basicConfig(level=logging.DEBUG,\n                        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')\n\nat the beginning of your script.\n\nYou can also use logs in your application by calling ``logging.getLogger()`` and setting the log level you want:\n\n.. code:: python\n\n    logger = logging.getLogger()\n    logger.setLevel(logging.INFO)\n\nIf you want DEBUG logs instead:\n\n.. code:: python\n\n    logger.setLevel(logging.DEBUG)\n\n\n=============\nDocumentation\n=============\n\n``python-telegram-bot``'s documentation lives at `readthedocs.io <https://python-telegram-bot.readthedocs.io/>`_.\n\n============\nGetting help\n============\n\nYou can get help in several ways:\n\n1. We have a vibrant community of developers helping each other in our `Telegram group <https://telegram.me/pythontelegrambotgroup>`_. Join us!\n\n2. Report bugs, request new features or ask questions by `creating an issue <https://github.com/python-telegram-bot/python-telegram-bot/issues/new/choose>`_.\n\n3. Our `Wiki pages <https://github.com/python-telegram-bot/python-telegram-bot/wiki/>`_ offer a growing amount of resources.\n\n4. You can even ask for help on Stack Overflow using the `python-telegram-bot tag <https://stackoverflow.com/questions/tagged/python-telegram-bot>`_.\n\n\n\n============\nContributing\n============\n\nContributions of all sizes are welcome. Please review our `contribution guidelines <https://github.com/python-telegram-bot/python-telegram-bot/blob/master/.github/CONTRIBUTING.rst>`_ to get started. You can also help by `reporting bugs <https://github.com/python-telegram-bot/python-telegram-bot/issues/new>`_.\n\n=======\nLicense\n=======\n\nYou may copy, distribute and modify the software provided that modifications are described and licensed for free under `LGPL-3 <https://www.gnu.org/licenses/lgpl-3.0.html>`_. Derivatives works (including modifications or anything statically linked to the library) can only be redistributed under LGPL-3, but applications that use the library don't have to be.\n",
    'author': 'Michael DM Dryden',
    'author_email': 'mk.dryden@utoronto.ca',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
